@@ -15,12 +15,15 @@ import static org.wildfly.extension.messaging.activemq.CommonAttributes.REMOTE_A
 import static org.wildfly.extension.messaging.activemq.CommonAttributes.REMOTE_CONNECTOR;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.CONFIGURATION_MASTER_PATH;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.CONFIGURATION_SLAVE_PATH;
+import static org.wildfly.extension.messaging.activemq.MessagingExtension.REPLICATION_COLOCATED_PATH;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.REPLICATION_MASTER_PATH;
+import static org.wildfly.extension.messaging.activemq.MessagingExtension.SHARED_STORE_COLOCATED_PATH;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.SHARED_STORE_MASTER_PATH;
 import static org.wildfly.extension.messaging.activemq.MessagingExtension.SHARED_STORE_SLAVE_PATH;
 
 import org.jboss.as.controller.PersistentResourceXMLDescription;
 import org.jboss.as.controller.PersistentResourceXMLParser;
+import org.jboss.as.controller.PersistentResourceXMLDescription.PersistentResourceXMLBuilder;
 import org.wildfly.extension.messaging.activemq.ha.HAAttributes;
 import org.wildfly.extension.messaging.activemq.ha.ScaleDownAttributes;
 import org.wildfly.extension.messaging.activemq.jms.ConnectionFactoryAttributes;
@@ -28,27 +31,120 @@ import org.wildfly.extension.messaging.activemq.jms.bridge.JMSBridgeDefinition;
 import org.wildfly.extension.messaging.activemq.jms.legacy.LegacyConnectionFactoryDefinition;
 
 /**
- * Parser and Marshaller for messaging-activemq's {@link #NAMESPACE}.
+ * @author wangc
  *
- * <em>All resources and attributes must be listed explicitly and not through any collections.</em>
- * This ensures that if the resource definitions change in later version (e.g. a new attribute is added),
- * this will have no impact on parsing this specific version of the subsystem.
- *
- * @author <a href="http://jmesnil.net/">Jeff Mesnil</a> (c) 2015 Red Hat inc.
  */
-public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
+public class MessagingSubsystemParser_13_0 extends PersistentResourceXMLParser {
 
-    static final String NAMESPACE = "urn:jboss:domain:messaging-activemq:2.0";
+    static final String NAMESPACE = "urn:jboss:domain:messaging-activemq:13.0";
 
     @Override
-    public PersistentResourceXMLDescription getParserDescription(){
+    public PersistentResourceXMLDescription getParserDescription() {
+
+        final PersistentResourceXMLBuilder jgroupDiscoveryGroup = builder(JGroupsDiscoveryGroupDefinition.PATH)
+                .addAttributes(
+                        DiscoveryGroupDefinition.JGROUPS_CHANNEL_FACTORY,
+                        DiscoveryGroupDefinition.JGROUPS_CHANNEL,
+                        CommonAttributes.JGROUPS_CLUSTER,
+                        DiscoveryGroupDefinition.REFRESH_TIMEOUT,
+                        DiscoveryGroupDefinition.INITIAL_WAIT_TIMEOUT);
+
+        final PersistentResourceXMLBuilder socketDiscoveryGroup = builder(SocketDiscoveryGroupDefinition.PATH)
+                .addAttributes(
+                        CommonAttributes.SOCKET_BINDING,
+                        DiscoveryGroupDefinition.REFRESH_TIMEOUT,
+                        DiscoveryGroupDefinition.INITIAL_WAIT_TIMEOUT);
+
+        final PersistentResourceXMLBuilder remoteConnector = builder(pathElement(REMOTE_CONNECTOR))
+                .addAttributes(
+                        RemoteTransportDefinition.SOCKET_BINDING,
+                        CommonAttributes.PARAMS);
+
+        final PersistentResourceXMLBuilder httpConnector = builder(MessagingExtension.HTTP_CONNECTOR_PATH)
+                .addAttributes(
+                        HTTPConnectorDefinition.SOCKET_BINDING,
+                        HTTPConnectorDefinition.ENDPOINT,
+                        HTTPConnectorDefinition.SERVER_NAME,
+                        CommonAttributes.PARAMS);
+
+        final PersistentResourceXMLBuilder invmConnector = builder(pathElement(IN_VM_CONNECTOR))
+                .addAttributes(
+                        InVMTransportDefinition.SERVER_ID,
+                        CommonAttributes.PARAMS);
+
+        final PersistentResourceXMLBuilder connector = builder(pathElement(CONNECTOR))
+                .addAttributes(
+                        GenericTransportDefinition.SOCKET_BINDING,
+                        CommonAttributes.FACTORY_CLASS,
+                        CommonAttributes.PARAMS);
+
         return builder(MessagingExtension.SUBSYSTEM_PATH, NAMESPACE)
                 .addAttributes(
                         MessagingSubsystemRootResourceDefinition.GLOBAL_CLIENT_THREAD_POOL_MAX_SIZE,
                         MessagingSubsystemRootResourceDefinition.GLOBAL_CLIENT_SCHEDULED_THREAD_POOL_MAX_SIZE)
-                .addChild(builder(MessagingExtension.SERVER_PATH)
-                                .addAttributes(
-                                        // no attribute groups
+                .addChild(httpConnector)
+                .addChild(remoteConnector)
+                .addChild(invmConnector)
+                .addChild(connector)
+                .addChild(jgroupDiscoveryGroup)
+                .addChild(socketDiscoveryGroup)
+                .addChild(builder(MessagingExtension.CONNECTION_FACTORY_PATH)
+                        .addAttributes(
+                                CommonAttributes.HA,
+                                ConnectionFactoryAttributes.Regular.FACTORY_TYPE,
+                                ConnectionFactoryAttributes.Common.DISCOVERY_GROUP,
+                                ConnectionFactoryAttributes.Common.CONNECTORS,
+                                ConnectionFactoryAttributes.Common.ENTRIES,
+                                ConnectionFactoryAttributes.External.ENABLE_AMQ1_PREFIX,
+                                ConnectionFactoryAttributes.Common.USE_TOPOLOGY,
+                                // common
+                                ConnectionFactoryAttributes.Common.CLIENT_FAILURE_CHECK_PERIOD,
+                                ConnectionFactoryAttributes.Common.CONNECTION_TTL,
+                                CommonAttributes.CALL_TIMEOUT,
+                                CommonAttributes.CALL_FAILOVER_TIMEOUT,
+                                ConnectionFactoryAttributes.Common.CONSUMER_WINDOW_SIZE,
+                                ConnectionFactoryAttributes.Common.CONSUMER_MAX_RATE,
+                                ConnectionFactoryAttributes.Common.CONFIRMATION_WINDOW_SIZE,
+                                ConnectionFactoryAttributes.Common.PRODUCER_WINDOW_SIZE,
+                                ConnectionFactoryAttributes.Common.PRODUCER_MAX_RATE,
+                                ConnectionFactoryAttributes.Common.PROTOCOL_MANAGER_FACTORY,
+                                ConnectionFactoryAttributes.Common.COMPRESS_LARGE_MESSAGES,
+                                ConnectionFactoryAttributes.Common.CACHE_LARGE_MESSAGE_CLIENT,
+                                CommonAttributes.MIN_LARGE_MESSAGE_SIZE,
+                                CommonAttributes.CLIENT_ID,
+                                ConnectionFactoryAttributes.Common.DUPS_OK_BATCH_SIZE,
+                                ConnectionFactoryAttributes.Common.TRANSACTION_BATCH_SIZE,
+                                ConnectionFactoryAttributes.Common.BLOCK_ON_ACKNOWLEDGE,
+                                ConnectionFactoryAttributes.Common.BLOCK_ON_NON_DURABLE_SEND,
+                                ConnectionFactoryAttributes.Common.BLOCK_ON_DURABLE_SEND,
+                                ConnectionFactoryAttributes.Common.AUTO_GROUP,
+                                ConnectionFactoryAttributes.Common.PRE_ACKNOWLEDGE,
+                                ConnectionFactoryAttributes.Common.RETRY_INTERVAL,
+                                ConnectionFactoryAttributes.Common.RETRY_INTERVAL_MULTIPLIER,
+                                CommonAttributes.MAX_RETRY_INTERVAL,
+                                ConnectionFactoryAttributes.Common.RECONNECT_ATTEMPTS,
+                                ConnectionFactoryAttributes.Common.FAILOVER_ON_INITIAL_CONNECTION,
+                                ConnectionFactoryAttributes.Common.CONNECTION_LOAD_BALANCING_CLASS_NAME,
+                                ConnectionFactoryAttributes.Common.USE_GLOBAL_POOLS,
+                                ConnectionFactoryAttributes.Common.SCHEDULED_THREAD_POOL_MAX_SIZE,
+                                ConnectionFactoryAttributes.Common.THREAD_POOL_MAX_SIZE,
+                                ConnectionFactoryAttributes.Common.GROUP_ID,
+                                ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
+                                ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
+                                ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE
+                        ))
+                .addChild(createPooledConnectionFactory(true))
+                .addChild(builder(MessagingExtension.EXTERNAL_JMS_QUEUE_PATH)
+                        .addAttributes(
+                                ConnectionFactoryAttributes.Common.ENTRIES
+                        ))
+                .addChild(builder(MessagingExtension.EXTERNAL_JMS_TOPIC_PATH)
+                        .addAttributes(
+                                ConnectionFactoryAttributes.Common.ENTRIES
+                        ))
+                .addChild(
+                        builder(MessagingExtension.SERVER_PATH)
+                                .addAttributes(// no attribute groups
                                         ServerDefinition.PERSISTENCE_ENABLED,
                                         ServerDefinition.PERSIST_ID_CACHE,
                                         ServerDefinition.PERSIST_DELIVERY_COUNT_BEFORE_DELIVERY,
@@ -84,9 +180,11 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                         ServerDefinition.JOURNAL_FILE_SIZE,
                                         ServerDefinition.JOURNAL_MIN_FILES,
                                         ServerDefinition.JOURNAL_POOL_FILES,
+                                        ServerDefinition.JOURNAL_FILE_OPEN_TIMEOUT,
                                         ServerDefinition.JOURNAL_COMPACT_PERCENTAGE,
                                         ServerDefinition.JOURNAL_COMPACT_MIN_FILES,
                                         ServerDefinition.JOURNAL_MAX_IO,
+                                        ServerDefinition.JOURNAL_MAX_ATTIC_FILES,
                                         ServerDefinition.CREATE_BINDINGS_DIR,
                                         ServerDefinition.CREATE_JOURNAL_DIR,
                                         ServerDefinition.JOURNAL_DATASOURCE,
@@ -95,8 +193,14 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                         ServerDefinition.JOURNAL_JMS_BINDINGS_TABLE,
                                         ServerDefinition.JOURNAL_LARGE_MESSAGES_TABLE,
                                         ServerDefinition.JOURNAL_PAGE_STORE_TABLE,
+                                        ServerDefinition.JOURNAL_NODE_MANAGER_STORE_TABLE,
                                         ServerDefinition.JOURNAL_DATABASE,
+                                        ServerDefinition.JOURNAL_JDBC_LOCK_EXPIRATION,
+                                        ServerDefinition.JOURNAL_JDBC_LOCK_RENEW_PERIOD,
                                         ServerDefinition.JOURNAL_JDBC_NETWORK_TIMEOUT,
+                                        ServerDefinition.GLOBAL_MAX_DISK_USAGE,
+                                        ServerDefinition.DISK_SCAN_PERIOD,
+                                        ServerDefinition.GLOBAL_MAX_MEMORY_SIZE,
                                         // statistics
                                         ServerDefinition.STATISTICS_ENABLED,
                                         ServerDefinition.MESSAGE_COUNTER_SAMPLE_PERIOD,
@@ -114,7 +218,19 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                         ServerDefinition.MEMORY_MEASURE_INTERVAL,
                                         ServerDefinition.MEMORY_WARNING_THRESHOLD,
                                         CommonAttributes.INCOMING_INTERCEPTORS,
-                                        CommonAttributes.OUTGOING_INTERCEPTORS)
+                                        CommonAttributes.OUTGOING_INTERCEPTORS,
+                                        //Network Isolation
+                                        ServerDefinition.NETWORK_CHECK_LIST,
+                                        ServerDefinition.NETWORK_CHECK_NIC,
+                                        ServerDefinition.NETWORK_CHECK_PERIOD,
+                                        ServerDefinition.NETWORK_CHECK_PING6_COMMAND,
+                                        ServerDefinition.NETWORK_CHECK_PING_COMMAND,
+                                        ServerDefinition.NETWORK_CHECK_TIMEOUT,
+                                        ServerDefinition.NETWORK_CHECK_URL_LIST,
+                                        ServerDefinition.CRITICAL_ANALYZER_ENABLED,
+                                        ServerDefinition.CRITICAL_ANALYZER_CHECK_PERIOD,
+                                        ServerDefinition.CRITICAL_ANALYZER_POLICY,
+                                        ServerDefinition.CRITICAL_ANALYZER_TIMEOUT)
                                 .addChild(
                                         builder(MessagingExtension.LIVE_ONLY_PATH)
                                                 .addAttributes(
@@ -142,7 +258,8 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         ScaleDownAttributes.SCALE_DOWN_GROUP_NAME,
                                                         ScaleDownAttributes.SCALE_DOWN_DISCOVERY_GROUP,
                                                         ScaleDownAttributes.SCALE_DOWN_CONNECTORS))
-                                .addChild(builder(MessagingExtension.REPLICATION_COLOCATED_PATH)
+                                .addChild(
+                                        builder(REPLICATION_COLOCATED_PATH)
                                                 .addAttributes(
                                                         HAAttributes.REQUEST_BACKUP,
                                                         HAAttributes.BACKUP_REQUEST_RETRIES,
@@ -182,7 +299,8 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         ScaleDownAttributes.SCALE_DOWN_GROUP_NAME,
                                                         ScaleDownAttributes.SCALE_DOWN_DISCOVERY_GROUP,
                                                         ScaleDownAttributes.SCALE_DOWN_CONNECTORS))
-                                .addChild(builder(MessagingExtension.SHARED_STORE_COLOCATED_PATH)
+                                .addChild(
+                                        builder(SHARED_STORE_COLOCATED_PATH)
                                                 .addAttributes(
                                                         HAAttributes.REQUEST_BACKUP,
                                                         HAAttributes.BACKUP_REQUEST_RETRIES,
@@ -224,10 +342,10 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         PathDefinition.RELATIVE_TO))
                                 .addChild(
                                         builder(MessagingExtension.QUEUE_PATH)
-                                                .addAttributes(
-                                                        QueueDefinition.ADDRESS,
+                                                .addAttributes(QueueDefinition.ADDRESS,
                                                         CommonAttributes.DURABLE,
-                                                        CommonAttributes.FILTER))
+                                                        CommonAttributes.FILTER,
+                                                        QueueDefinition.ROUTING_TYPE))
                                 .addChild(
                                         builder(MessagingExtension.SECURITY_SETTING_PATH)
                                                 .addChild(
@@ -262,30 +380,15 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         AddressSettingDefinition.SLOW_CONSUMER_POLICY,
                                                         AddressSettingDefinition.SLOW_CONSUMER_THRESHOLD,
                                                         AddressSettingDefinition.AUTO_CREATE_JMS_QUEUES,
-                                                        AddressSettingDefinition.AUTO_DELETE_JMS_QUEUES))
-                                .addChild(
-                                        builder(MessagingExtension.HTTP_CONNECTOR_PATH)
-                                                .addAttributes(
-                                                        HTTPConnectorDefinition.SOCKET_BINDING,
-                                                        HTTPConnectorDefinition.ENDPOINT,
-                                                        HTTPConnectorDefinition.SERVER_NAME,
-                                                        CommonAttributes.PARAMS))
-                                .addChild(
-                                        builder(pathElement(REMOTE_CONNECTOR))
-                                                .addAttributes(
-                                                        RemoteTransportDefinition.SOCKET_BINDING,
-                                                        CommonAttributes.PARAMS))
-                                .addChild(
-                                        builder(pathElement(IN_VM_CONNECTOR))
-                                                .addAttributes(
-                                                        InVMTransportDefinition.SERVER_ID,
-                                                        CommonAttributes.PARAMS))
-                                .addChild(
-                                        builder(pathElement(CONNECTOR))
-                                                .addAttributes(
-                                                        GenericTransportDefinition.SOCKET_BINDING,
-                                                        CommonAttributes.FACTORY_CLASS,
-                                                        CommonAttributes.PARAMS))
+                                                        AddressSettingDefinition.AUTO_DELETE_JMS_QUEUES,
+                                                        AddressSettingDefinition.AUTO_CREATE_QUEUES,
+                                                        AddressSettingDefinition.AUTO_DELETE_QUEUES,
+                                                        AddressSettingDefinition.AUTO_CREATE_ADDRESSES,
+                                                        AddressSettingDefinition.AUTO_DELETE_ADDRESSES))
+                                .addChild(httpConnector)
+                                .addChild(remoteConnector)
+                                .addChild(invmConnector)
+                                .addChild(connector)
                                 .addChild(
                                         builder(MessagingExtension.HTTP_ACCEPTOR_PATH)
                                                 .addAttributes(
@@ -309,21 +412,21 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         CommonAttributes.FACTORY_CLASS,
                                                         CommonAttributes.PARAMS))
                                 .addChild(
-                                        builder(MessagingExtension.BROADCAST_GROUP_PATH)
+                                        builder(MessagingExtension.JGROUPS_BROADCAST_GROUP_PATH)
                                                 .addAttributes(
-                                                        CommonAttributes.SOCKET_BINDING,
                                                         BroadcastGroupDefinition.JGROUPS_CHANNEL_FACTORY,
-                                                        CommonAttributes.JGROUPS_CHANNEL,
+                                                        BroadcastGroupDefinition.JGROUPS_CHANNEL,
+                                                        CommonAttributes.JGROUPS_CLUSTER,
                                                         BroadcastGroupDefinition.BROADCAST_PERIOD,
                                                         BroadcastGroupDefinition.CONNECTOR_REFS))
                                 .addChild(
-                                        builder(DiscoveryGroupDefinition.PATH)
+                                        builder(MessagingExtension.SOCKET_BROADCAST_GROUP_PATH)
                                                 .addAttributes(
                                                         CommonAttributes.SOCKET_BINDING,
-                                                        DiscoveryGroupDefinition.JGROUPS_CHANNEL_FACTORY,
-                                                        CommonAttributes.JGROUPS_CHANNEL,
-                                                        DiscoveryGroupDefinition.REFRESH_TIMEOUT,
-                                                        DiscoveryGroupDefinition.INITIAL_WAIT_TIMEOUT))
+                                                        BroadcastGroupDefinition.BROADCAST_PERIOD,
+                                                        BroadcastGroupDefinition.CONNECTOR_REFS))
+                                .addChild(jgroupDiscoveryGroup)
+                                .addChild(socketDiscoveryGroup)
                                 .addChild(
                                         builder(MessagingExtension.CLUSTER_CONNECTION_PATH)
                                                 .addAttributes(
@@ -390,7 +493,8 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         BridgeDefinition.PASSWORD,
                                                         BridgeDefinition.CREDENTIAL_REFERENCE,
                                                         BridgeDefinition.CONNECTOR_REFS,
-                                                        BridgeDefinition.DISCOVERY_GROUP_NAME))
+                                                        BridgeDefinition.DISCOVERY_GROUP_NAME,
+                                                        BridgeDefinition.CALL_TIMEOUT))
                                 .addChild(
                                         builder(MessagingExtension.CONNECTOR_SERVICE_PATH)
                                                 .addAttributes(
@@ -449,8 +553,9 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         ConnectionFactoryAttributes.Common.GROUP_ID,
                                                         ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
                                                         ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
-                                                        // regular
-                                                        ConnectionFactoryAttributes.Regular.FACTORY_TYPE))
+                                                        ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE,
+                                                        ConnectionFactoryAttributes.Regular.FACTORY_TYPE,
+                                                        ConnectionFactoryAttributes.Common.USE_TOPOLOGY))
                                 .addChild(
                                         builder(MessagingExtension.LEGACY_CONNECTION_FACTORY_PATH)
                                                 .addAttributes(
@@ -491,70 +596,7 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                                                         LegacyConnectionFactoryDefinition.THREAD_POOL_MAX_SIZE,
                                                         LegacyConnectionFactoryDefinition.TRANSACTION_BATCH_SIZE,
                                                         LegacyConnectionFactoryDefinition.USE_GLOBAL_POOLS))
-                                .addChild(
-                                        builder(MessagingExtension.POOLED_CONNECTION_FACTORY_PATH)
-                                                .addAttributes(
-                                                        ConnectionFactoryAttributes.Common.ENTRIES,
-                                                        // common
-                                                        ConnectionFactoryAttributes.Common.DISCOVERY_GROUP,
-                                                        ConnectionFactoryAttributes.Common.CONNECTORS,
-                                                        CommonAttributes.HA,
-                                                        ConnectionFactoryAttributes.Common.CLIENT_FAILURE_CHECK_PERIOD,
-                                                        ConnectionFactoryAttributes.Common.CONNECTION_TTL,
-                                                        CommonAttributes.CALL_TIMEOUT,
-                                                        CommonAttributes.CALL_FAILOVER_TIMEOUT,
-                                                        ConnectionFactoryAttributes.Common.CONSUMER_WINDOW_SIZE,
-                                                        ConnectionFactoryAttributes.Common.CONSUMER_MAX_RATE,
-                                                        ConnectionFactoryAttributes.Common.CONFIRMATION_WINDOW_SIZE,
-                                                        ConnectionFactoryAttributes.Common.PRODUCER_WINDOW_SIZE,
-                                                        ConnectionFactoryAttributes.Common.PRODUCER_MAX_RATE,
-                                                        ConnectionFactoryAttributes.Common.PROTOCOL_MANAGER_FACTORY,
-                                                        ConnectionFactoryAttributes.Common.COMPRESS_LARGE_MESSAGES,
-                                                        ConnectionFactoryAttributes.Common.CACHE_LARGE_MESSAGE_CLIENT,
-                                                        CommonAttributes.MIN_LARGE_MESSAGE_SIZE,
-                                                        CommonAttributes.CLIENT_ID,
-                                                        ConnectionFactoryAttributes.Common.DUPS_OK_BATCH_SIZE,
-                                                        ConnectionFactoryAttributes.Common.TRANSACTION_BATCH_SIZE,
-                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_ACKNOWLEDGE,
-                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_NON_DURABLE_SEND,
-                                                        ConnectionFactoryAttributes.Common.BLOCK_ON_DURABLE_SEND,
-                                                        ConnectionFactoryAttributes.Common.AUTO_GROUP,
-                                                        ConnectionFactoryAttributes.Common.PRE_ACKNOWLEDGE,
-                                                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL,
-                                                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL_MULTIPLIER,
-                                                        CommonAttributes.MAX_RETRY_INTERVAL,
-                                                        ConnectionFactoryAttributes.Common.RECONNECT_ATTEMPTS,
-                                                        ConnectionFactoryAttributes.Common.FAILOVER_ON_INITIAL_CONNECTION,
-                                                        ConnectionFactoryAttributes.Common.CONNECTION_LOAD_BALANCING_CLASS_NAME,
-                                                        ConnectionFactoryAttributes.Common.USE_GLOBAL_POOLS,
-                                                        ConnectionFactoryAttributes.Common.SCHEDULED_THREAD_POOL_MAX_SIZE,
-                                                        ConnectionFactoryAttributes.Common.THREAD_POOL_MAX_SIZE,
-                                                        ConnectionFactoryAttributes.Common.GROUP_ID,
-                                                        ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
-                                                        ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
-                                                        // pooled
-                                                        // inbound config
-                                                        ConnectionFactoryAttributes.Pooled.USE_JNDI,
-                                                        ConnectionFactoryAttributes.Pooled.JNDI_PARAMS,
-                                                        ConnectionFactoryAttributes.Pooled.REBALANCE_CONNECTIONS,
-                                                        ConnectionFactoryAttributes.Pooled.USE_LOCAL_TX,
-                                                        ConnectionFactoryAttributes.Pooled.SETUP_ATTEMPTS,
-                                                        ConnectionFactoryAttributes.Pooled.SETUP_INTERVAL,
-                                                        // outbound config
-                                                        ConnectionFactoryAttributes.Pooled.ALLOW_LOCAL_TRANSACTIONS,
-
-                                                        ConnectionFactoryAttributes.Pooled.TRANSACTION,
-                                                        ConnectionFactoryAttributes.Pooled.USER,
-                                                        ConnectionFactoryAttributes.Pooled.PASSWORD,
-                                                        ConnectionFactoryAttributes.Pooled.CREDENTIAL_REFERENCE,
-                                                        ConnectionFactoryAttributes.Pooled.MIN_POOL_SIZE,
-                                                        ConnectionFactoryAttributes.Pooled.USE_AUTO_RECOVERY,
-                                                        ConnectionFactoryAttributes.Pooled.MAX_POOL_SIZE,
-                                                        ConnectionFactoryAttributes.Pooled.MANAGED_CONNECTION_POOL,
-                                                        ConnectionFactoryAttributes.Pooled.ENLISTMENT_TRACE,
-                                                        ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE,
-                                                        ConnectionFactoryAttributes.Pooled.INITIAL_CONNECT_ATTEMPTS,
-                                                        ConnectionFactoryAttributes.Pooled.STATISTICS_ENABLED)))
+                                .addChild(createPooledConnectionFactory(false)))
                 .addChild(
                         builder(MessagingExtension.JMS_BRIDGE_PATH)
                                 .addAttributes(
@@ -583,4 +625,74 @@ public class MessagingSubsystemParser_2_0 extends PersistentResourceXMLParser {
                 .build();
     }
 
+    private PersistentResourceXMLBuilder createPooledConnectionFactory(boolean external) {
+        PersistentResourceXMLBuilder builder = builder(MessagingExtension.POOLED_CONNECTION_FACTORY_PATH)
+                .addAttributes(
+                        ConnectionFactoryAttributes.Common.ENTRIES,
+                        // common
+                        ConnectionFactoryAttributes.Common.DISCOVERY_GROUP,
+                        ConnectionFactoryAttributes.Common.CONNECTORS,
+                        CommonAttributes.HA,
+                        ConnectionFactoryAttributes.Common.CLIENT_FAILURE_CHECK_PERIOD,
+                        ConnectionFactoryAttributes.Common.CONNECTION_TTL,
+                        CommonAttributes.CALL_TIMEOUT,
+                        CommonAttributes.CALL_FAILOVER_TIMEOUT,
+                        ConnectionFactoryAttributes.Common.CONSUMER_WINDOW_SIZE,
+                        ConnectionFactoryAttributes.Common.CONSUMER_MAX_RATE,
+                        ConnectionFactoryAttributes.Common.CONFIRMATION_WINDOW_SIZE,
+                        ConnectionFactoryAttributes.Common.PRODUCER_WINDOW_SIZE,
+                        ConnectionFactoryAttributes.Common.PRODUCER_MAX_RATE,
+                        ConnectionFactoryAttributes.Common.PROTOCOL_MANAGER_FACTORY,
+                        ConnectionFactoryAttributes.Common.COMPRESS_LARGE_MESSAGES,
+                        ConnectionFactoryAttributes.Common.CACHE_LARGE_MESSAGE_CLIENT,
+                        CommonAttributes.MIN_LARGE_MESSAGE_SIZE,
+                        CommonAttributes.CLIENT_ID,
+                        ConnectionFactoryAttributes.Common.DUPS_OK_BATCH_SIZE,
+                        ConnectionFactoryAttributes.Common.TRANSACTION_BATCH_SIZE,
+                        ConnectionFactoryAttributes.Common.BLOCK_ON_ACKNOWLEDGE,
+                        ConnectionFactoryAttributes.Common.BLOCK_ON_NON_DURABLE_SEND,
+                        ConnectionFactoryAttributes.Common.BLOCK_ON_DURABLE_SEND,
+                        ConnectionFactoryAttributes.Common.AUTO_GROUP,
+                        ConnectionFactoryAttributes.Common.PRE_ACKNOWLEDGE,
+                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL,
+                        ConnectionFactoryAttributes.Common.RETRY_INTERVAL_MULTIPLIER,
+                        CommonAttributes.MAX_RETRY_INTERVAL,
+                        ConnectionFactoryAttributes.Common.RECONNECT_ATTEMPTS,
+                        ConnectionFactoryAttributes.Common.FAILOVER_ON_INITIAL_CONNECTION,
+                        ConnectionFactoryAttributes.Common.CONNECTION_LOAD_BALANCING_CLASS_NAME,
+                        ConnectionFactoryAttributes.Common.USE_GLOBAL_POOLS,
+                        ConnectionFactoryAttributes.Common.SCHEDULED_THREAD_POOL_MAX_SIZE,
+                        ConnectionFactoryAttributes.Common.THREAD_POOL_MAX_SIZE,
+                        ConnectionFactoryAttributes.Common.GROUP_ID,
+                        ConnectionFactoryAttributes.Common.DESERIALIZATION_BLACKLIST,
+                        ConnectionFactoryAttributes.Common.DESERIALIZATION_WHITELIST,
+                        ConnectionFactoryAttributes.Common.USE_TOPOLOGY,
+                        // pooled
+                        // inbound config
+                        ConnectionFactoryAttributes.Pooled.USE_JNDI,
+                        ConnectionFactoryAttributes.Pooled.JNDI_PARAMS,
+                        ConnectionFactoryAttributes.Pooled.REBALANCE_CONNECTIONS,
+                        ConnectionFactoryAttributes.Pooled.USE_LOCAL_TX,
+                        ConnectionFactoryAttributes.Pooled.SETUP_ATTEMPTS,
+                        ConnectionFactoryAttributes.Pooled.SETUP_INTERVAL,
+                        // outbound config
+                        ConnectionFactoryAttributes.Pooled.ALLOW_LOCAL_TRANSACTIONS,
+                        ConnectionFactoryAttributes.Pooled.TRANSACTION,
+                        ConnectionFactoryAttributes.Pooled.USER,
+                        ConnectionFactoryAttributes.Pooled.PASSWORD,
+                        ConnectionFactoryAttributes.Pooled.CREDENTIAL_REFERENCE,
+                        ConnectionFactoryAttributes.Pooled.MIN_POOL_SIZE,
+                        ConnectionFactoryAttributes.Pooled.USE_AUTO_RECOVERY,
+                        ConnectionFactoryAttributes.Pooled.MAX_POOL_SIZE,
+                        ConnectionFactoryAttributes.Pooled.MANAGED_CONNECTION_POOL,
+                        ConnectionFactoryAttributes.Pooled.ENLISTMENT_TRACE,
+                        ConnectionFactoryAttributes.Common.INITIAL_MESSAGE_PACKET_SIZE,
+                        ConnectionFactoryAttributes.Pooled.INITIAL_CONNECT_ATTEMPTS,
+                        ConnectionFactoryAttributes.Pooled.STATISTICS_ENABLED);
+        if (external) {
+            builder.addAttributes(ConnectionFactoryAttributes.External.ENABLE_AMQ1_PREFIX);
+        }
+        return builder;
+    }
+
 }
